==> MTOS-5.2.tar.gz: MTOS-5.2/mt-static/mt_fr.js <==
/* Movable Type language lexicon for fr localization. */

Lexicon['Are you sure you want to remove the filter \'[_1]\'?'] = 'Voulez-vous vraiment retirer le filtre \'[_1]\'?';
Lexicon['Insert/Edit Link'] = 'Insérer/éditer un lien';
Lexicon['You have unsaved changes to this page that will be lost.'] = 'Certains de vos changements dans cette page n\'ont pas été enregistrés: ils seront perdus.';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = 'Dernière sauvegarde automatique à [_1]: [_2]: [_3]';
Lexicon['Tag must have a valid name'] = 'Le tag doit avoir un nom valide';
Lexicon['Cancel'] = 'Annuler';
Lexicon['Fullscreen'] = 'Plein écran';
Lexicon['[_1] &ndash; [_2] of [_3]'] = '[_1] &ndash; [_2] de [_3]';
Lexicon['Italic (Ctrl+I)'] = 'Italique (Ctrl+I)';
Lexicon['Loading...'] = 'Chargement...';
Lexicon['Auto-saving...'] = 'Sauvegarde automatique...';
Lexicon['delete'] = 'supprimer';
Lexicon['No Preview Available.'] = 'Pas de prévisualisation disponible';
Lexicon['You have [quant,_1,registration,registrations] from [_2]'] = 'Vous avez [quant,_1,création de compte,créations de compte] sur [_2]';
Lexicon['Enter URL:'] = 'Saisissez l\'URL :';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' et \'[_2]\' sur tous les blogs ?';
Lexicon['Select Filter'] = 'Sélectionner le filtre';
Lexicon['[_1] - [_2] of [_3]'] = '[_1] - [_2] de [_3]';
Lexicon['Outdent'] = 'Désindenter';
Lexicon['This field must be an integer'] = 'Ce champ doit être un entier';
Lexicon['Insert Image Asset'] = 'Insérer une image';
Lexicon['enable'] = 'activer';
Lexicon['Unlink'] = 'Délier';
Lexicon['Next'] = 'Suivant';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = 'Vous ne pouvez agir que sur un maximum de [_1] [_2].';
Lexicon['Block Quotation'] = 'Bloc de citation';
Lexicon['Invalid URL'] = 'URL incorrecte';
Lexicon['Indent'] = 'Indenter';
Lexicon['Label \"[_1]\" is already in use.'] = 'Le label \"[_1]\" est déjà en cours d\'utilisation';
Lexicon['This field is required'] = 'Ce champ est requis';
Lexicon['remove'] = 'retirer';
Lexicon['Remove'] = 'Retirer';
Lexicon['Enter email address:'] = 'Saisissez l\'adresse e-mail:';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = 'Vous avez \<a href=\'[_3]\'\>[quant,_1,note,notes] de [_2]\<\/a\>';
Lexicon['Invalid date format'] = 'Format de date incorrect';
Lexicon['Horizontal Line'] = 'Ligne horizontale';
Lexicon['Prev'] = 'Précédent';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = 'Voulez-vous vraiment [_3] les [_1] [_2] sélectionné(e)s ?';
Lexicon['This field must be a number'] = 'Ce champ doit être un nombre';
Lexicon['[_1] \'[_2]\' already exists.'] = '[_1] \'[_2]\' existe déjà.';
Lexicon['Invalid email address'] = 'Adresse e-mail invalide.';
Lexicon['[_1] contains a character that is invalid when used in a directory name: [_2]'] = '[_1] contient un caractère non valide lorsqu\'utilisé dans un nom de répertoire: [_2]';
Lexicon['Remove Formatting'] = 'Supprimer le formatage';
Lexicon['You must select an action.'] = 'Vous devez sélectionner une action.';
Lexicon['File Name'] = 'Nom de fichier';
Lexicon['List Item'] = 'Item de liste';
Lexicon['Add sub folder'] = 'Ajouter un sous-dossier';
Lexicon['Ordered List'] = 'Liste ordonnée';
Lexicon['Close'] = 'Fermer';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' avec \'[_2]\' sur tous les blogs ?';
Lexicon['Strikethrough'] = 'Rayé';
Lexicon['Insert Link'] = 'Insérer un lien';
Lexicon['Make primary'] = 'Rendre principal';
Lexicon['Select Text Color'] = 'Choisir la couleur du texte';
Lexicon['Bold (Ctrl+B)'] = 'Gras (Ctrl+B)';
Lexicon['Last'] = 'Dernier';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = 'Voulez-vous vraiment supprimer les rôles [_1] ? Avec cette action vous allez supprimer les autorisations associées à tous les utilisateurs et groupes liés à ce rôle.';
Lexicon['Underline (Ctrl+U)'] = 'Souligné (Ctrl+U)';
Lexicon['unlock'] = 'déverrouiller';
Lexicon['to mark as spam'] = 'pour classer comme spam';
Lexicon['All [_1] items are selected'] = 'Tous les [_1] éléments sont sélectionnés';
Lexicon['Are you sure you want to remove [_1] [_2]?'] = 'Voulez-vous vraiment retirer [_1] [_2]?';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = 'Voulez-vous vraiment supprimer ce rôle ? En faisant cela vous allez supprimer les autorisations de tous les utilisateurs et groupes associés à ce rôle.';
Lexicon['Are you sure you want to remove [_1] [_2] with [_3] sub [_4]?'] = 'Voulez-vous vraiment retirer [_1] [_2] avec [_3] sous [_4]?';
Lexicon['You did not select any [_1] to [_2].'] = 'Vous n\'avez pas sélectionné de [_1] à [_2].';
Lexicon['Toggle Fullscreen Mode'] = 'Bascule plein écran';
Lexicon['None selected'] = 'Aucune sélectionnée';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = 'Vous avez \<a href=\'[_3]\'\>[quant,_1,commentaire,commentaires] de [_2]\<\/a\>';
Lexicon['Strong Emphasis'] = 'Forte emphase';
Lexicon['disable'] = 'désactiver';
Lexicon['Insert HTML'] = 'Insérer du HTML';
Lexicon['Save Filter'] = 'Enregistrer le filtre';
Lexicon['Select all [_1] items'] = 'Sélectionner tous les [_1] éléments';
Lexicon['Emphasis'] = 'Emphase';
Lexicon['(None)'] = '(Aucun)';
Lexicon['Align Left'] = 'Aligner à gauche';
Lexicon['[_1] - Filter [_2]'] = '[_1] - Filtre [_2]';
Lexicon['publish'] = 'publier';
Lexicon['Add sub category'] = 'Ajouter une sous-catégorie';
Lexicon['Invalid login.'] = 'Identifiant invalide.';
Lexicon['Insert Asset Link'] = 'Insérer un lien de fichier';
Lexicon['[_1] Filter Items have errors'] = '[_1] éléments du filtre comportent des erreurs';
Lexicon['Communication Error ([_1])'] = 'Erreur de communication ([_1])';
Lexicon['Alert'] = 'Alerte';
Lexicon['Select Background Color'] = 'Choisir la couleur du fond';
Lexicon['Redo (Ctrl+Y)'] = 'Refaire (Ctrl+Y)';
Lexicon['Invalid value'] = 'Valeur incorrecte';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '[_1]Publiez[_2] votre site pour que ces changements soient appliqués.';
Lexicon['Label is required.'] = 'Le label est requis';
Lexicon['Toggle HTML Edit Mode'] = 'Bascule mode code HTML';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = 'Vous ne pouvez agir que sur un minimum de [_1] [_2].';
Lexicon['to remove spam status'] = 'pour retirer le statut de spam';
Lexicon['Unordered List'] = 'Liste non ordonnée';
Lexicon['Align Right'] = 'Aligner à droite';
Lexicon['Align Center'] = 'Aligner au centre';
Lexicon['You have an error in your input.'] = 'Il y a une erreur dans votre entrée.';
Lexicon['Save As Filter'] = 'Enregistrer comme filtre';
Lexicon['You did not select any [_1] [_2].'] = 'Vous n\'avez pas sélectionné de [_1] [_2].';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' avec \'[_2]\' ?';
Lexicon['No [_1] could be found.'] = 'Il n\'y a pas de [_1] trouvés.';
Lexicon['Undo (Ctrl+Z)'] = 'Annuler (Ctrl+Z)';
Lexicon['First'] = 'Premier';
Lexicon['Are you sure you want to [_2] this [_1]?'] = 'Voulez-vous vraiment [_2] cet(te) [_1] ?';

==> MTOS-5.2.3.tar.gz: MTOS-5.2.3/mt-static/mt_fr.js <==
/* Movable Type language lexicon for fr localization. */

Lexicon['Are you sure you want to remove the filter \'[_1]\'?'] = 'Voulez-vous vraiment retirer le filtre \'[_1]\'?';
Lexicon['Insert/Edit Link'] = 'Insérer/éditer un lien';
Lexicon['You have unsaved changes to this page that will be lost.'] = 'Certains de vos changements dans cette page n\'ont pas été enregistrés: ils seront perdus.';
Lexicon['Last auto-save at [_1]:[_2]:[_3]'] = 'Dernière sauvegarde automatique à [_1]: [_2]: [_3]';
Lexicon['Tag must have a valid name'] = 'Le tag doit avoir un nom valide';
Lexicon['Cancel'] = 'Annuler';
Lexicon['configuration directive'] = 'directive de configuration';
Lexicon['Fullscreen'] = 'Plein écran';
Lexicon['[_1] &ndash; [_2] of [_3]'] = '[_1] &ndash; [_2] de [_3]';
Lexicon['Italic (Ctrl+I)'] = 'Italique (Ctrl+I)';
Lexicon['A configuration value is required.'] = 'Une valeur de configuration est requise.';
Lexicon['Loading...'] = 'Chargement...';
Lexicon['Auto-saving...'] = 'Sauvegarde automatique...';
Lexicon['delete'] = 'supprimer';
Lexicon['No Preview Available.'] = 'Pas de prévisualisation disponible';
Lexicon['You have [quant,_1,registration,registrations] from [_2]'] = 'Vous avez [quant,_1,création de compte,créations de compte] sur [_2]';
Lexicon['Enter URL:'] = 'Saisissez l\'URL :';
Lexicon['Preview'] = 'Aperçu';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all blogs?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' et \'[_2]\' sur tous les blogs ?';
Lexicon['Select Filter'] = 'Sélectionner le filtre';
Lexicon['[_1] - [_2] of [_3]'] = '[_1] - [_2] de [_3]';
Lexicon['Outdent'] = 'Désindenter';
Lexicon['This field must be an integer'] = 'Ce champ doit être un entier';
Lexicon['Insert Image Asset'] = 'Insérer une image';
Lexicon['enable'] = 'activer';
Lexicon['Unlink'] = 'Délier';
Lexicon['Next'] = 'Suivant';
Lexicon['You can only act upon a maximum of [_1] [_2].'] = 'Vous ne pouvez agir que sur un maximum de [_1] [_2].';
Lexicon['[_1] already exists.'] = '[_1] existe déjà.';
Lexicon['Block Quotation'] = 'Bloc de citation';
Lexicon['Invalid URL'] = 'URL incorrecte';
Lexicon['Indent'] = 'Indenter';
Lexicon['Label \"[_1]\" is already in use.'] = 'Le label \"[_1]\" est déjà en cours d\'utilisation';
Lexicon['This field is required'] = 'Ce champ est requis';
Lexicon['remove'] = 'retirer';
Lexicon['Remove'] = 'Retirer';
Lexicon['Enter email address:'] = 'Saisissez l\'adresse e-mail:';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,entry,entries] from [_2]\<\/a\>'] = 'Vous avez \<a href=\'[_3]\'\>[quant,_1,note,notes] de [_2]\<\/a\>';
Lexicon['[_1] cannot be updated.'] = '[_1] ne peut pas être mis à jour.';
Lexicon['Invalid date format'] = 'Format de date incorrect';
Lexicon['Horizontal Line'] = 'Ligne horizontale';
Lexicon['Prev'] = 'Précédent';
Lexicon['Are you sure you want to [_3] the [_1] selected [_2]?'] = 'Voulez-vous vraiment [_3] les [_1] [_2] sélectionné(e)s ?';
Lexicon['This field must be a number'] = 'Ce champ doit être un nombre';
Lexicon['[_1] \'[_2]\' already exists.'] = '[_1] \'[_2]\' existe déjà.';
Lexicon['Invalid email address'] = 'Adresse e-mail invalide.';
Lexicon['[_1] contains a character that is invalid when used in a directory name: [_2]'] = '[_1] contient un caractère non valide lorsqu\'utilisé dans un nom de répertoire: [_2]';
Lexicon['Remove Formatting'] = 'Supprimer le formatage';
Lexicon['A configuration directive is required.'] = 'Une directive de configuration est requise.';
Lexicon['You must select an action.'] = 'Vous devez sélectionner une action.';
Lexicon['File Name'] = 'Nom de fichier';
Lexicon['List Item'] = 'Item de liste';
Lexicon['Add sub folder'] = 'Ajouter un sous-dossier';
Lexicon['Ordered List'] = 'Liste ordonnée';
Lexicon['Close'] = 'Fermer';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\' across all weblogs?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' avec \'[_2]\' sur tous les blogs ?';
Lexicon['Select Boilerplate'] = 'Sélectionnez le texte formaté';
Lexicon['Strikethrough'] = 'Rayé';
Lexicon['[_1] for [_2] already exists.'] = '[_1] pour [_2] existe déjà.';
Lexicon['Insert Link'] = 'Insérer un lien';
Lexicon['Make primary'] = 'Rendre principal';
Lexicon['Select Text Color'] = 'Choisir la couleur du texte';
Lexicon['Bold (Ctrl+B)'] = 'Gras (Ctrl+B)';
Lexicon['Last'] = 'Dernier';
Lexicon['Are you certain you want to remove these [_1] roles? By doing so you will be taking away the permissions currently assigned to any users and groups associated with these roles.'] = 'Voulez-vous vraiment supprimer les rôles [_1] ? Avec cette action vous allez supprimer les autorisations associées à tous les utilisateurs et groupes liés à ce rôle.';
Lexicon['Underline (Ctrl+U)'] = 'Souligné (Ctrl+U)';
Lexicon['Although [_1] can be updated by Movable Type, it cannot be updated on this screen.'] = 'Bien que [_1] puisse être mis à jour par Movable Type, il ne peut l\'être via cet écran.';
Lexicon['unlock'] = 'déverrouiller';
Lexicon['to mark as spam'] = 'pour classer comme spam';
Lexicon['All [_1] items are selected'] = 'Tous les [_1] éléments sont sélectionnés';
Lexicon['Are you sure you want to remove [_1] [_2]?'] = 'Voulez-vous vraiment retirer [_1] [_2]?';
Lexicon['Are you certain you want to remove this role? By doing so you will be taking away the permissions currently assigned to any users and groups associated with this role.'] = 'Voulez-vous vraiment supprimer ce rôle ? En faisant cela vous allez supprimer les autorisations de tous les utilisateurs et groupes associés à ce rôle.';
Lexicon['Are you sure you want to remove [_1] [_2] with [_3] sub [_4]?'] = 'Voulez-vous vraiment retirer [_1] [_2] avec [_3] sous [_4]?';
Lexicon['You did not select any [_1] to [_2].'] = 'Vous n\'avez pas sélectionné de [_1] à [_2].';
Lexicon['Boilerplate'] = 'Texte formaté';
Lexicon['Toggle Fullscreen Mode'] = 'Bascule plein écran';
Lexicon['None selected'] = 'Aucune sélectionnée';
Lexicon['You have \<a href=\'[_3]\'\>[quant,_1,comment,comments] from [_2]\<\/a\>'] = 'Vous avez \<a href=\'[_3]\'\>[quant,_1,commentaire,commentaires] de [_2]\<\/a\>';
Lexicon['Strong Emphasis'] = 'Forte emphase';
Lexicon['disable'] = 'désactiver';
Lexicon['Insert HTML'] = 'Insérer du HTML';
Lexicon['Save Filter'] = 'Enregistrer le filtre';
Lexicon['Select all [_1] items'] = 'Sélectionner tous les [_1] éléments';
Lexicon['Emphasis'] = 'Emphase';
Lexicon['(None)'] = '(Aucun)';
Lexicon['Align Left'] = 'Aligner à gauche';
Lexicon['[_1] - Filter [_2]'] = '[_1] - Filtre [_2]';
Lexicon['publish'] = 'publier';
Lexicon['Are you sure you want to remove [_1]?'] = 'Voulez-vous vraiment supprimer [_1] ?';
Lexicon['Name'] = 'Nom';
Lexicon['Add sub category'] = 'Ajouter une sous-catégorie';
Lexicon['Invalid login.'] = 'Identifiant invalide.';
Lexicon['Insert Asset Link'] = 'Insérer un lien de fichier';
Lexicon['[_1] Filter Items have errors'] = '[_1] éléments du filtre comportent des erreurs';
Lexicon['Communication Error ([_1])'] = 'Erreur de communication ([_1])';
Lexicon['Alert'] = 'Alerte';
Lexicon['Select Background Color'] = 'Choisir la couleur du fond';
Lexicon['Redo (Ctrl+Y)'] = 'Refaire (Ctrl+Y)';
Lexicon['Invalid value'] = 'Valeur incorrecte';
Lexicon['[_1]Publish[_2] your site to see these changes take effect.'] = '[_1]Publiez[_2] votre site pour que ces changements soient appliqués.';
Lexicon['Insert Boilerplate'] = 'Insérez le texte formaté';
Lexicon['Label is required.'] = 'Le label est requis';
Lexicon['Toggle HTML Edit Mode'] = 'Bascule mode code HTML';
Lexicon['You can only act upon a minimum of [_1] [_2].'] = 'Vous ne pouvez agir que sur un minimum de [_1] [_2].';
Lexicon['to remove spam status'] = 'pour retirer le statut de spam';
Lexicon['Unordered List'] = 'Liste non ordonnée';
Lexicon['Align Right'] = 'Aligner à droite';
Lexicon['Align Center'] = 'Aligner au centre';
Lexicon['You have an error in your input.'] = 'Il y a une erreur dans votre entrée.';
Lexicon['Continue'] = 'Continuer';
Lexicon['Save As Filter'] = 'Enregistrer comme filtre';
Lexicon['You did not select any [_1] [_2].'] = 'Vous n\'avez pas sélectionné de [_1] [_2].';
Lexicon['The tag \'[_2]\' already exists. Are you sure you want to merge \'[_1]\' with \'[_2]\'?'] = 'Le tag \'[_2]\' existe déjà. Voulez-vous vraiment fusionner \'[_1]\' avec \'[_2]\' ?';
Lexicon['The HASH type configuration directive should be in the format of \"key=value\"'] = 'La directive de configuration de type HASH doit être au format \"clé=valeur\"';
Lexicon['No [_1] could be found.'] = 'Il n\'y a pas de [_1] trouvés.';
Lexicon['Undo (Ctrl+Z)'] = 'Annuler (Ctrl+Z)';
Lexicon['First'] = 'Premier';
Lexicon['Are you sure you want to [_2] this [_1]?'] = 'Voulez-vous vraiment [_2] cet(te) [_1] ?';
